@@ -26,6 +26,9 @@ Our module for everything related to the Nautilus extension.
 
 """
 from __future__ import with_statement
+from __future__ import absolute_import
+import six
+from six.moves import range
 
 def log_all_exceptions(type, value, tb):
     import sys, traceback
@@ -40,7 +43,7 @@ def log_all_exceptions(type, value, tb):
     try:
         import rabbitvcs.ui.dialog
         rabbitvcs.ui.dialog.ErrorNotification(text)
-    except Exception, ex:
+    except Exception as ex:
         log.exception("Additional exception when attempting"
                       " to display error dialog.")
         log.exception(ex)
@@ -188,7 +191,7 @@ class RabbitVCS(nautilus.InfoProvider, nautilus.MenuProvider,
                 
         if not self.valid_uri(item.get_uri()): return nautilus.OPERATION_FAILED
         
-        path = unicode(gnomevfs.get_local_path_from_uri(item.get_uri()), "utf-8")
+        path = six.text_type(gnomevfs.get_local_path_from_uri(item.get_uri()), "utf-8")
 
         # log.debug("update_file_info() called for %s" % path)
 
@@ -218,7 +221,7 @@ class RabbitVCS(nautilus.InfoProvider, nautilus.MenuProvider,
         status = None
         # Could replace with (st for st in self.... if st.path ...).next()
         # Need to catch exception
-        for idx in xrange(len(self.statuses_from_callback)):
+        for idx in range(len(self.statuses_from_callback)):
             found = (self.statuses_from_callback[idx].path) == path
             if found: break
 
@@ -271,7 +274,7 @@ class RabbitVCS(nautilus.InfoProvider, nautilus.MenuProvider,
             "age": age
         }
 
-        for key, value in values.items():
+        for key, value in list(values.items()):
             item.add_string_attribute(key, value)
 
     def update_status(self, item, path, status):
@@ -306,7 +309,7 @@ class RabbitVCS(nautilus.InfoProvider, nautilus.MenuProvider,
         paths = []
         for item in items:
             if self.valid_uri(item.get_uri()):
-                path = unicode(gnomevfs.get_local_path_from_uri(item.get_uri()), "utf-8")
+                path = six.text_type(gnomevfs.get_local_path_from_uri(item.get_uri()), "utf-8")
                 paths.append(path)
                 self.nautilusVFSFile_table[path] = item
 
@@ -334,7 +337,7 @@ class RabbitVCS(nautilus.InfoProvider, nautilus.MenuProvider,
         paths = []
         for item in items:
             if self.valid_uri(item.get_uri()):
-                path = unicode(gnomevfs.get_local_path_from_uri(item.get_uri()), "utf-8")
+                path = six.text_type(gnomevfs.get_local_path_from_uri(item.get_uri()), "utf-8")
                 paths.append(path)
                 self.nautilusVFSFile_table[path] = item
 
@@ -356,7 +359,7 @@ class RabbitVCS(nautilus.InfoProvider, nautilus.MenuProvider,
         import cProfile
         import rabbitvcs.util.helper
         
-        path = unicode(gnomevfs.get_local_path_from_uri(item.get_uri()),
+        path = six.text_type(gnomevfs.get_local_path_from_uri(item.get_uri()),
                        "utf-8").replace("/", ":")
         
         profile_data_file = os.path.join(
@@ -386,7 +389,7 @@ class RabbitVCS(nautilus.InfoProvider, nautilus.MenuProvider,
         """
 
         if not self.valid_uri(item.get_uri()): return
-        path = unicode(gnomevfs.get_local_path_from_uri(item.get_uri()), "utf-8")
+        path = six.text_type(gnomevfs.get_local_path_from_uri(item.get_uri()), "utf-8")
         self.nautilusVFSFile_table[path] = item
 
         # log.debug("get_background_items_full() called")
@@ -409,7 +412,7 @@ class RabbitVCS(nautilus.InfoProvider, nautilus.MenuProvider,
 
     def get_background_items(self, window, item):
         if not self.valid_uri(item.get_uri()): return
-        path = unicode(gnomevfs.get_local_path_from_uri(item.get_uri()), "utf-8")
+        path = six.text_type(gnomevfs.get_local_path_from_uri(item.get_uri()), "utf-8")
         self.nautilusVFSFile_table[path] = item
 
         # log.debug("get_background_items() called")
@@ -546,7 +549,7 @@ class RabbitVCS(nautilus.InfoProvider, nautilus.MenuProvider,
 
         for item in items:
             if self.valid_uri(item.get_uri()):
-                path = unicode(gnomevfs.get_local_path_from_uri(item.get_uri()), "utf-8")
+                path = six.text_type(gnomevfs.get_local_path_from_uri(item.get_uri()), "utf-8")
                 
                 if self.vcs_client.is_in_a_or_a_working_copy(path):
                     paths.append(path)
