@@ -10,6 +10,8 @@ All rights reserved. This program and the accompanying materials are made
 available under the terms of the BSD which accompanies this distribution, and 
 is available at U{http://www.opensource.org/licenses/bsd-license.php}
 '''
+from __future__ import absolute_import
+from __future__ import print_function
 
 import gtk, gobject
 import re
@@ -17,7 +19,9 @@ import sys
 import os
 import pango
 from StringIO import StringIO
-import thread
+import six.moves._thread
+from six.moves import range
+from functools import reduce
 
 try:
   import IPython
@@ -219,11 +223,11 @@ class IterableIPShell:
     @type header: string
     '''
     stat = 0
-    if verbose or debug: print header+cmd
+    if verbose or debug: print(header+cmd)
     # flush stdout so we don't mangle python's buffering
     if not debug:
       input, output = os.popen4(cmd)
-      print output.read()
+      print(output.read())
       output.close()
       input.close()
 
