@@ -1,3 +1,4 @@
+from __future__ import absolute_import
 #
 # This is an extension to the Nautilus file manager to allow better 
 # integration with the Subversion source control system.
@@ -35,6 +36,7 @@ import pysvn
 import configobj
 
 from rabbitvcs import gettext
+from six.moves import map
 _ = gettext.gettext
 
 class About:
@@ -81,8 +83,8 @@ class About:
         self.about.set_authors(authors.split("\n"))
         
         versions = []
-        versions.append("Subversion - %s" % string.join(map(str,pysvn.svn_version), "."))
-        versions.append("Pysvn - %s" % string.join(map(str,pysvn.version), "."))
+        versions.append("Subversion - %s" % string.join(list(map(str,pysvn.svn_version)), "."))
+        versions.append("Pysvn - %s" % string.join(list(map(str,pysvn.version)), "."))
         versions.append("ConfigObj - %s" % str(configobj.__version__))
         
         self.about.set_comments("\n".join(versions))
