@@ -1,3 +1,4 @@
+from __future__ import absolute_import
 #
 # This is an extension to the Nautilus file manager to allow better 
 # integration with the Subversion source control system.
@@ -74,7 +75,7 @@ class Delete(InterfaceNonView):
             if versioned:
                 try:
                     self.vcs_remove(versioned, force=True)
-                except Exception, e:
+                except Exception as e:
                     log.exception()
                     return
             
