@@ -21,6 +21,7 @@
 #
 
 from __future__ import division
+from __future__ import absolute_import
 import threading
 from datetime import datetime
 
@@ -41,6 +42,8 @@ import rabbitvcs.vcs
 from rabbitvcs.util.decorators import gtk_unsafe
 
 from rabbitvcs import gettext
+import six
+from six.moves import range
 _ = gettext.gettext
 
 DATETIME_FORMAT = rabbitvcs.util.helper.LOCAL_DATETIME_FORMAT
@@ -64,10 +67,10 @@ def revision_grapher(history):
     last_lines = []
     color = "#d3b9d3"
     for item in history:
-        commit = unicode(item.revision)
+        commit = six.text_type(item.revision)
         parents = []
         for parent in item.parents:
-            parents.append(unicode(parent))
+            parents.append(six.text_type(parent))
 
         if commit not in revisions:
             revisions.append(commit)
@@ -221,11 +224,11 @@ class Log(InterfaceView):
 
     def on_paths_table_row_activated(self, treeview, data=None, col=None):
         try:
-            revision1 = unicode(self.display_items[self.revisions_table.get_selected_rows()[0]].revision)
-            revision2 = unicode(self.display_items[self.revisions_table.get_selected_rows()[0]+1].revision)
+            revision1 = six.text_type(self.display_items[self.revisions_table.get_selected_rows()[0]].revision)
+            revision2 = six.text_type(self.display_items[self.revisions_table.get_selected_rows()[0]+1].revision)
             path_item = self.paths_table.get_row(self.paths_table.get_selected_rows()[0])[1]
             url = self.root_url + path_item
-            self.view_diff_for_path(url, unicode(revision1), unicode(revision2), sidebyside=True)
+            self.view_diff_for_path(url, six.text_type(revision1), six.text_type(revision2), sidebyside=True)
         except IndexError:
             pass
 
@@ -247,12 +250,12 @@ class Log(InterfaceView):
 
             try:
                 line["next_revision"] = self.display_items[row+1].revision
-            except IndexError,e:
+            except IndexError as e:
                 pass
 
             try:
                 line["previous_revision"] = self.display_items[row-1].revision
-            except IndexError,e:
+            except IndexError as e:
                 pass          
                       
             revisions.append(line)
@@ -315,12 +318,12 @@ class Log(InterfaceView):
             }
             try:
                 line["next_revision"] = self.display_items[row+1].revision
-            except IndexError,e:
+            except IndexError as e:
                 pass
 
             try:
                 line["previous_revision"] = self.display_items[row-1].revision
-            except IndexError,e:
+            except IndexError as e:
                 pass          
                       
             revisions.append(line)
@@ -436,8 +439,8 @@ class SVNLog(Log):
             return
         
         # Get the starting/ending point from the actual returned revisions
-        self.rev_start = unicode(self.revision_items[0].revision)
-        self.rev_end = unicode(self.revision_items[-1].revision)
+        self.rev_start = six.text_type(self.revision_items[0].revision)
+        self.rev_end = six.text_type(self.revision_items[-1].revision)
 
         if not self.rev_first:
             self.rev_first = self.rev_start
@@ -491,7 +494,7 @@ class SVNLog(Log):
 
     def populate_table(self, revision, author, date, msg, color):
         self.revisions_table.append([
-            unicode(revision),
+            six.text_type(revision),
             author,
             rabbitvcs.util.helper.format_datetime(date),
             msg,
@@ -559,9 +562,9 @@ class SVNLog(Log):
         for selected_row in self.revisions_table.get_selected_rows():
             item = self.display_items[selected_row]
             
-            text += "%s: %s\n" % (REVISION_LABEL, unicode(item.revision))
-            text += "%s: %s\n" % (AUTHOR_LABEL, unicode(item.author))
-            text += "%s: %s\n" % (DATE_LABEL, unicode(item.date))
+            text += "%s: %s\n" % (REVISION_LABEL, six.text_type(item.revision))
+            text += "%s: %s\n" % (AUTHOR_LABEL, six.text_type(item.author))
+            text += "%s: %s\n" % (DATE_LABEL, six.text_type(item.date))
             text += "%s\n\n"   % item.message
             if item.changed_paths is not None:
                 for subitem in item.changed_paths:
@@ -589,7 +592,7 @@ class SVNLog(Log):
                 indented_message = item.message.replace("\n","\n\t")
                 self.message.append_text(
 					"%s %s:\n\t%s\n" % (REVISION_LABEL,
-                                        unicode(item.revision),
+                                        six.text_type(item.revision),
                                         indented_message))
             if item.changed_paths is not None:
                 for subitem in item.changed_paths:
@@ -676,8 +679,7 @@ class GitLog(Log):
                 "row-activated":    self.on_paths_table_row_activated
             },
             flags={
-                "sortable": True, 
-                "sort_on": 1
+                "sortable": False
             }
         )
         self.start_point = 0
@@ -703,7 +705,30 @@ class GitLog(Log):
         
         if not self.revision_items or len(self.revision_items) == 0:
             return
-        
+
+        # Load tags.
+        self.tagItems = []
+        for tag in self.tagAction.get_result(0):
+            name = tag.name
+
+            # Determine the type of tag, so we know which id to use.
+            if "Tag" in str([tag.obj]):
+                # Tag object, use the dereferenced id.
+                id = tag.obj.object[1]
+            else:
+                # Commit object, use the sha id.
+                id = tag.sha
+
+            # Add tags to list so we can match on id and display in the message.
+            self.tagItems.append({'id': id, 'name': name})
+
+        # Load branches.
+        self.branchItems = []
+        for branch in self.branchAction.get_result(0):
+            if branch.name.startswith("remotes/"):
+                branch.name = branch.name[len("remotes/"):]
+            self.branchItems.append({'id': branch.revision, 'name': branch.name})
+
         self.set_start_revision(self.revision_items[0].revision.short())
         self.set_end_revision(self.revision_items[-1].revision.short())
 
@@ -715,7 +740,7 @@ class GitLog(Log):
             should_add = not self.filter_text
             should_add = should_add or msg.find(self.filter_text) > -1
             should_add = should_add or item.author.lower().find(self.filter_text) > -1
-            should_add = should_add or unicode(item.revision).lower().find(self.filter_text) > -1
+            should_add = should_add or six.text_type(item.revision).lower().find(self.filter_text) > -1
             should_add = should_add or str(item.date).lower().find(self.filter_text) > -1
 
             if should_add:
@@ -734,7 +759,7 @@ class GitLog(Log):
 
         index = 0
         for (item, node, in_lines, out_lines) in grapher:
-            revision = unicode(item.revision)
+            revision = six.text_type(item.revision)
             msg = cgi.escape(rabbitvcs.util.helper.format_long_text(item.message, 80))
             author = item.author
             date = rabbitvcs.util.helper.format_datetime(item.date)
@@ -749,6 +774,16 @@ class GitLog(Log):
             if not self.filter_text:
                 graph_render = (node, in_lines, out_lines)
 
+            # Check if a branch is available for this revision, and if so, insert it in the message description.
+            for branch in self.branchItems:
+                if branch['id'] == revision:
+                    msg = "<b>[" + branch['name'] + "]</b> " + msg
+
+            # Check if a tag is available for this revision, and if so, insert it in the message description.
+            for tag in self.tagItems:
+                if tag['id'] == revision:
+                    msg = "<i>[" + tag['name'] + "]</i> " + msg
+
             self.revisions_table.append([
                 graph_render,
                 revision,
@@ -766,6 +801,27 @@ class GitLog(Log):
     def load(self):
         self.set_loading(True)
 
+        # Load branches.
+        self.branchAction = GitAction(
+            self.git,
+            notification=False,
+            run_in_thread=True
+        )
+
+        self.branchAction.append(self.git.branch_list)
+        self.branchAction.start();
+
+        # Load tags.
+        self.tagAction = GitAction(
+            self.git,
+            notification=False,
+            run_in_thread=True
+        )
+
+        self.tagAction.append(self.git.tag_list)
+        self.tagAction.start()
+
+        # Load log.
         self.action = GitAction(
             self.git,
             notification=False,
@@ -786,9 +842,9 @@ class GitLog(Log):
         for selected_row in self.revisions_table.get_selected_rows():
             item = self.display_items[selected_row]
 
-            text += "%s: %s\n" % (REVISION_LABEL, unicode(item.revision.short()))
-            text += "%s: %s\n" % (AUTHOR_LABEL, unicode(item.author))
-            text += "%s: %s\n" % (DATE_LABEL, unicode(item.date))
+            text += "%s: %s\n" % (REVISION_LABEL, six.text_type(item.revision.short()))
+            text += "%s: %s\n" % (AUTHOR_LABEL, six.text_type(item.author))
+            text += "%s: %s\n" % (DATE_LABEL, six.text_type(item.date))
             text += "%s\n\n" % item.message
             
         self.revision_clipboard.set_text(text)
@@ -819,7 +875,7 @@ class GitLog(Log):
                         subitem.path
                     ])
 
-        subitems.sort(lambda x, y: cmp(x[1],y[1]))
+#        subitems.sort(lambda x, y: cmp(x[1],y[1]))
         for subitem in subitems:
             self.paths_table.append([
                 subitem[0],
@@ -1084,17 +1140,17 @@ class LogTopContextMenuCallbacks:
 
     def find_parent(self, revision):
         if ("parents" in revision) and len(revision["parents"]) > 0:
-            parent = unicode(revision["parents"][0])
+            parent = six.text_type(revision["parents"][0])
         elif ("next_revision" in revision):
-            parent = unicode(revision["next_revision"])
+            parent = six.text_type(revision["next_revision"])
         else:
-            parent = unicode(int(unicode(revision["revision"])) - 1)
+            parent = six.text_type(int(six.text_type(revision["revision"])) - 1)
 
         return parent
         
     def view_diff_working_copy(self, widget, data=None):
         rabbitvcs.util.helper.launch_ui_window("diff", [
-            "%s@%s" % (self.path, unicode(self.revisions[0]["revision"])),
+            "%s@%s" % (self.path, six.text_type(self.revisions[0]["revision"])),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
 
@@ -1106,7 +1162,7 @@ class LogTopContextMenuCallbacks:
 
         rabbitvcs.util.helper.launch_ui_window("diff", [
             "%s@%s" % (self.path, parent),
-            "%s@%s" % (self.path, unicode(self.revisions[0]["revision"])),
+            "%s@%s" % (self.path, six.text_type(self.revisions[0]["revision"])),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
 
@@ -1117,7 +1173,7 @@ class LogTopContextMenuCallbacks:
     
         rabbitvcs.util.helper.launch_ui_window("diff", [
             "%s@%s" % (path_older, self.revisions[1]["revision"].value),
-            "%s@%s" % (self.path, unicode(self.revisions[0]["revision"])),
+            "%s@%s" % (self.path, six.text_type(self.revisions[0]["revision"])),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
 
@@ -1128,7 +1184,7 @@ class LogTopContextMenuCallbacks:
     
         rabbitvcs.util.helper.launch_ui_window("diff", [
             "-s",
-            "%s@%s" % (path_older, unicode(self.revisions[0]["revision"])),
+            "%s@%s" % (path_older, six.text_type(self.revisions[0]["revision"])),
             "%s" % (self.path),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
@@ -1139,7 +1195,7 @@ class LogTopContextMenuCallbacks:
         rabbitvcs.util.helper.launch_ui_window("diff", [
             "-s",
             "%s@%s" % (self.path, parent),
-            "%s@%s" % (self.path, unicode(self.revisions[0]["revision"])),
+            "%s@%s" % (self.path, six.text_type(self.revisions[0]["revision"])),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
 
@@ -1151,12 +1207,12 @@ class LogTopContextMenuCallbacks:
         rabbitvcs.util.helper.launch_ui_window("diff", [
             "-s",
             "%s@%s" % (path_older, self.revisions[1]["revision"].value),
-            "%s@%s" % (self.path, unicode(self.revisions[0]["revision"])),
+            "%s@%s" % (self.path, six.text_type(self.revisions[0]["revision"])),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
 
     def show_changes_previous_revision(self, widget, data=None):
-        rev_first = unicode(self.revisions[0]["revision"])
+        rev_first = six.text_type(self.revisions[0]["revision"])
         parent = self.find_parent(self.revisions[0])
         
         path = self.path
@@ -1165,35 +1221,35 @@ class LogTopContextMenuCallbacks:
 
         rabbitvcs.util.helper.launch_ui_window("changes", [
             "%s@%s" % (path, parent),
-            "%s@%s" % (path, unicode(rev_first)),
+            "%s@%s" % (path, six.text_type(rev_first)),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
 
     def show_changes_revisions(self, widget, data=None):
-        rev_first = unicode(self.revisions[0]["revision"])
-        rev_last = unicode(self.revisions[0]["next_revision"])
+        rev_first = six.text_type(self.revisions[0]["revision"])
+        rev_last = six.text_type(self.revisions[0]["next_revision"])
 
         path = self.path
         if self.vcs_name == rabbitvcs.vcs.VCS_SVN:
             path = self.vcs.svn().get_repo_url(self.path)
 
         rabbitvcs.util.helper.launch_ui_window("changes", [
-            "%s@%s" % (path, unicode(rev_first)),
-            "%s@%s" % (path, unicode(rev_last)),
+            "%s@%s" % (path, six.text_type(rev_first)),
+            "%s@%s" % (path, six.text_type(rev_last)),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
 
     def update_to_this_revision(self, widget, data=None):        
         rabbitvcs.util.helper.launch_ui_window("updateto", [
             self.path,
-            "-r", unicode(self.revisions[0]["revision"]),
+            "-r", six.text_type(self.revisions[0]["revision"]),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
 
     def revert_changes_from_this_revision(self, widget, data=None):        
         rabbitvcs.util.helper.launch_ui_window("merge", [
             self.path,
-            unicode(self.revisions[0]["revision"]) + "-" + str(int(unicode(self.revisions[0]["revision"])) - 1),
+            six.text_type(self.revisions[0]["revision"]) + "-" + str(int(six.text_type(self.revisions[0]["revision"])) - 1),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])        
         
@@ -1205,46 +1261,46 @@ class LogTopContextMenuCallbacks:
         rabbitvcs.util.helper.launch_ui_window("checkout", [
             self.path, 
             url, 
-            "-r", unicode(self.revisions[0]["revision"]),
+            "-r", six.text_type(self.revisions[0]["revision"]),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
 
     def branch_tag(self, widget, data=None):
         rabbitvcs.util.helper.launch_ui_window("branch", [
             self.path, 
-            "-r", unicode(self.revisions[0]["revision"]),
+            "-r", six.text_type(self.revisions[0]["revision"]),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
 
     def branches(self, widget, data=None):
         rabbitvcs.util.helper.launch_ui_window("branches", [
             self.path, 
-            "-r", unicode(self.revisions[0]["revision"]),
+            "-r", six.text_type(self.revisions[0]["revision"]),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
 
     def tags(self, widget, data=None):
         rabbitvcs.util.helper.launch_ui_window("tags", [
             self.path, 
-            "-r", unicode(self.revisions[0]["revision"]),
+            "-r", six.text_type(self.revisions[0]["revision"]),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
         
     def export(self, widget, data=None):
         rabbitvcs.util.helper.launch_ui_window("export", [
             self.path, 
-            "-r", unicode(self.revisions[0]["revision"]),
+            "-r", six.text_type(self.revisions[0]["revision"]),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
 
     def merge(self, widget, data=None):
         extra = []
         if self.vcs_name == rabbitvcs.vcs.VCS_GIT:
-            extra.append(unicode(self.revisions[0]["revision"]))
+            extra.append(six.text_type(self.revisions[0]["revision"]))
             try:
-                fromrev = unicode(self.revisions[1]["revision"])
+                fromrev = six.text_type(self.revisions[1]["revision"])
                 extra.append(fromrev)
-            except IndexError, e:
+            except IndexError as e:
                 pass
         
         extra += ["--vcs=%s" % self.caller.get_vcs_name()]
@@ -1254,7 +1310,7 @@ class LogTopContextMenuCallbacks:
     def reset(self, widget, data=None):
         rabbitvcs.util.helper.launch_ui_window("reset", [
             self.path, 
-            "-r", unicode(self.revisions[0]["revision"]),
+            "-r", six.text_type(self.revisions[0]["revision"]),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
 
@@ -1286,7 +1342,7 @@ class LogTopContextMenuCallbacks:
         url = self.vcs.svn().get_repo_url(self.path)
         
         rabbitvcs.util.helper.launch_ui_window("revprops", [
-            "%s@%s" % (url, unicode(self.revisions[0]["revision"])),
+            "%s@%s" % (url, six.text_type(self.revisions[0]["revision"])),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
 
@@ -1423,16 +1479,16 @@ class LogBottomContextMenuCallbacks:
 
     def find_parent(self, revision):
         if ("parents" in revision) and len(revision["parents"]) > 0:
-            parent = unicode(revision["parents"][0])
+            parent = six.text_type(revision["parents"][0])
         elif ("next_revision" in revision):
-            parent = unicode(revision["next_revision"])
+            parent = six.text_type(revision["next_revision"])
         else:
-            parent = unicode(int(unicode(revision["revision"])) - 1)
+            parent = six.text_type(int(six.text_type(revision["revision"])) - 1)
 
         return parent
 
     def view_diff_previous_revision(self, widget, data=None):
-        rev = unicode(self.revisions[0]["revision"])
+        rev = six.text_type(self.revisions[0]["revision"])
 
         parent = self.find_parent(self.revisions[0])
 
@@ -1441,15 +1497,15 @@ class LogBottomContextMenuCallbacks:
         self.caller.view_diff_for_path(url, rev, parent)
 
     def view_diff_revisions(self, widget, data=None):
-        rev_first = unicode(self.revisions[0]["revision"])
-        rev_last = unicode(self.revisions[-1]["revision"])
+        rev_first = six.text_type(self.revisions[0]["revision"])
+        rev_last = six.text_type(self.revisions[-1]["revision"])
         path_item = self.paths[0]
         url = self.caller.root_url + path_item
         self.caller.view_diff_for_path(url, latest_revision_number=rev_last,
                                        earliest_revision_number=rev_first)
 
     def compare_previous_revision(self, widget, data=None):
-        rev = unicode(self.revisions[0]["revision"])
+        rev = six.text_type(self.revisions[0]["revision"])
         
         parent = self.find_parent(self.revisions[0])
             
@@ -1458,8 +1514,8 @@ class LogBottomContextMenuCallbacks:
         self.caller.view_diff_for_path(url, rev, parent, sidebyside=True)
     
     def compare_revisions(self, widget, data=None):
-        earliest_rev = unicode(self.revisions[0]["revision"])
-        latest_rev = unicode(self.revisions[-1]["revision"])
+        earliest_rev = six.text_type(self.revisions[0]["revision"])
+        latest_rev = six.text_type(self.revisions[-1]["revision"])
         path_item = self.paths[0]
         url = self.caller.root_url + path_item
         self.caller.view_diff_for_path(url,
@@ -1468,7 +1524,7 @@ class LogBottomContextMenuCallbacks:
                                         earliest_revision_number=earliest_rev)
 
     def show_changes_previous_revision(self, widget, data=None):
-        rev_first = unicode(self.revisions[0]["revision"])
+        rev_first = six.text_type(self.revisions[0]["revision"])
         
         parent = self.find_parent(self.revisions[0])
 
@@ -1483,8 +1539,8 @@ class LogBottomContextMenuCallbacks:
         ])
     
     def show_changes_revisions(self, widget, data=None):
-        rev_first = unicode(self.revisions[0]["revision"])
-        rev_last = unicode(self.revisions[-1]["revision"])
+        rev_first = six.text_type(self.revisions[0]["revision"])
+        rev_last = six.text_type(self.revisions[-1]["revision"])
 
         url = self.paths[0]
         if self.vcs_name == rabbitvcs.vcs.VCS_SVN:
@@ -1503,7 +1559,7 @@ class LogBottomContextMenuCallbacks:
             rabbitvcs.util.helper.launch_ui_window("open", [
                 path, 
                 "--vcs=%s" % self.vcs_name, 
-                "-r", unicode(self.revisions[0]["revision"])
+                "-r", six.text_type(self.revisions[0]["revision"])
             ])
 
     def annotate(self, widget, data=None):
@@ -1514,7 +1570,7 @@ class LogBottomContextMenuCallbacks:
         rabbitvcs.util.helper.launch_ui_window("annotate", [
             url, 
             "--vcs=%s" % self.vcs_name, 
-            "-r", unicode(self.revisions[0]["revision"])
+            "-r", six.text_type(self.revisions[0]["revision"])
         ])
 
 class LogBottomContextMenu:
@@ -1591,9 +1647,16 @@ dialogs_map = {
 }
 
 def log_factory(path, vcs):
+    # vcs option is allowed for URL only
+    if os.path.exists(path):
+        vcs = None
+
     if not vcs:
         guess = rabbitvcs.vcs.guess(path)
         vcs = guess["vcs"]
+        if not classes_map.has_key(vcs):
+            from rabbitvcs.ui import VCS_OPT_ERROR
+            raise SystemExit(VCS_OPT_ERROR)
 
     return classes_map[vcs](path)
 
