@@ -1,3 +1,4 @@
+from __future__ import absolute_import
 #
 # This is an extension to the Nautilus file manager to allow better 
 # integration with the Subversion source control system.
@@ -28,6 +29,9 @@ from rabbitvcs.util.log import Log
 logger = Log("rabbitvcs.vcs")
 
 from rabbitvcs.util.helper import get_exclude_paths
+from rabbitvcs.util.settings import SettingsManager
+
+settings = SettingsManager()
 
 EXT_UTIL_ERROR = _("The output from '%s' was not able to be processed.\n%s")
 
@@ -36,20 +40,20 @@ VCS_GIT = 'git'
 VCS_MERCURIAL = 'mercurial'
 VCS_DUMMY = 'unknown'
 
-def guess(path):
+def _guess(path):
     # Determine the VCS instance based on the path
     if path:
         path_to_check = path
         folders = {
             ".svn": VCS_SVN,
             ".git": VCS_GIT,
-            ".hg": VCS_MERCURIAL,
+            ".hg": VCS_DUMMY, # Disable this for now
             ".bzr": VCS_DUMMY,
             ".CVS": VCS_DUMMY
         }
         
         while path_to_check != "/" and path_to_check != "":
-            for folder, client in folders.items():
+            for folder, client in list(folders.items()):
                 if os.path.isdir(os.path.join(path_to_check, folder)):
                     cache = {
                         "vcs": client,
@@ -62,7 +66,7 @@ def guess(path):
     path_to_check = "./" + path.split("@")[0]
 
     while path_to_check != "/" and path_to_check != "":
-        for folder, client in folders.items():
+        for folder, client in list(folders.items()):
             if os.path.isdir(os.path.join(path_to_check, folder)):
                 cache = {
                     "vcs": client,
@@ -71,12 +75,20 @@ def guess(path):
                 return cache                
         path_to_check = os.path.split(path_to_check)[0]            
 
-
     return {
         "vcs": VCS_DUMMY,
         "repo_path": path
     }
 
+# Override the standard guessing method to ensure we
+# can return a dummy object if needed
+def guess(path):
+    obj = _guess(path)
+    if obj["vcs"] != VCS_DUMMY and settings.get("HideItem", obj["vcs"]):
+        return {"vcs": VCS_DUMMY, "repo_path": path}
+    else:
+        return obj
+
 class VCS:
     clients = {}
     exclude_paths = []
@@ -93,6 +105,9 @@ class VCS:
             return self.clients[VCS_DUMMY]
     
     def svn(self):
+        if settings.get("HideItem", "svn"):
+            return self.dummy()
+
         if VCS_SVN in self.clients:
             return self.clients[VCS_SVN]
         else:
@@ -100,15 +115,20 @@ class VCS:
                 from rabbitvcs.vcs.svn import SVN
                 self.clients[VCS_SVN] = SVN()
                 return self.clients[VCS_SVN]
-            except Exception, e:
+            except Exception as e:
                 logger.debug("Unable to load SVN module: %s" % e)
                 logger.exception(e)
                 self.clients[VCS_SVN] = self.dummy()
                 return self.clients[VCS_SVN]
 
     def git(self, path=None, is_repo_path=False):
+        if settings.get("HideItem", "git"):
+            return self.dummy()
+
         if VCS_GIT in self.clients:
             git = self.clients[VCS_GIT]
+            if git.__class__.__name__ == "Dummy":
+                return self.dummy()
 
             if path:
                 if is_repo_path:
@@ -132,13 +152,16 @@ class VCS:
                 
                 self.clients[VCS_GIT] = git
                 return self.clients[VCS_GIT]
-            except Exception, e:
+            except Exception as e:
                 logger.debug("Unable to load Git module: %s" % e)
                 logger.exception(e)
                 self.clients[VCS_GIT] = self.dummy()
                 return self.clients[VCS_GIT]
 
     def mercurial(self, path=None, is_repo_path=False):
+        if settings.get("HideItem", "hg"):
+            return self.dummy()
+
         if VCS_MERCURIAL in self.clients:
             mercurial = self.clients[VCS_MERCURIAL]
 
@@ -164,7 +187,7 @@ class VCS:
 
                 self.clients[VCS_MERCURIAL] = mercurial
                 return self.clients[VCS_MERCURIAL]
-            except Exception, e:
+            except Exception as e:
                 logger.debug("Unable to load Mercurial module: %s" % e)
                 logger.exception(e)
                 self.clients[VCS_MERCURIAL] = self.dummy()
