@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+from __future__ import print_function
 #
 # test/remote.py
 #
@@ -19,7 +21,7 @@ DIR = "remote"
 if options.cleanup:
     rmtree(DIR, ignore_errors=True)
 
-    print "remote.py clean"
+    print("remote.py clean")
 else:
     if os.path.isdir(DIR):
         raise SystemExit("This test script has already been run.  Please call this script with --cleanup to start again")
@@ -37,4 +39,4 @@ else:
     
     assert (len(l) == 0)
 
-    print "remote.py pass"
+    print("remote.py pass")
