@@ -1,3 +1,4 @@
+from __future__ import absolute_import
 #!/usr/bin/python
 
 from sys import argv
@@ -11,7 +12,6 @@ def cleanup(modules):
 modules = [
     "branch.py", 
     "stage.py",
-    "config.py",
     "commit.py",
     "tag.py",
     "remove.py",
