@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+from __future__ import print_function
 #
 # test/stage.py
 #
@@ -20,7 +22,7 @@ DIR = "tag"
 if options.cleanup:
     rmtree(DIR, ignore_errors=True)
 
-    print "tag.py clean"
+    print("tag.py clean")
 else:
     if os.path.isdir(DIR):
         raise SystemExit("This test script has already been run.  Please call this script with --cleanup to start again")
@@ -40,4 +42,4 @@ else:
     
     assert (len(g.tag_list()) == 1)
     
-    print "tag.py pass"
+    print("tag.py pass")
